About
=====

Nature-inspired algorithms are a very popular tool for solving optimization problems.
Since the beginning of their era, numerous variants of `nature-inspired algorithms were
developed <https://arxiv.org/abs/1307.4186>`_. To prove their versatility, those were
tested in various domains on various applications, especially when they are hybridized,
modified or adapted. However, implementation of nature-inspired algorithms is sometimes
difficult, complex and tedious task. In order to break this wall, NiaPy is intended for
simple and quick use, without spending a time for implementing algorithms from scratch.

Mission
-------
Our mission is to build a collection of nature-inspired algorithms and create a simple
interface for managing the optimization process along with statistical evaluation.
NiaPy offers:

- numerous optimization problem implementations,
- use of various nature-inspired algorithms without struggle and effort with a simple interface, and
- easy comparison between nature-inspired algorithms.

Licence
-------
This package is distributed under the `MIT License <http://www.opensource.org/licenses/MIT>`_.

Disclaimer
----------
This framework is provided as-is, and there are no guarantees that it fits your purposes
or that it is bug-free. Use it at your own risk!
